# When to use AI

## The Great AI Debate: When to Trust the Machine vs. When to Stick to Your Brain

As a journalist, software developer, and DevOps expert, I’ve spent years navigating the murky waters of AI’s “what if” scenarios. The question that keeps coming up professionally is: *“When to use AI?”* And the answer, like many things in life, is *“It depends.”* But when I’m not using my brain, I’m using my shudders. Let’s dive into the scenarios where AI isn’s the best choice—and where it *is* the best choice.

## When AI is Not the Best Choice

### 1. **The Fuzzy Logic Dilemma**

AI is great at handling *fuzzy logic*—like when you’re trying to figure out if a work order is “urgent” or “not urgent” based on vague descriptions. But when you’re trying to map a work type to a specific work request, AI is *not* the best choice. Imagine this: You have a dataset of work orders, each with a type (e.g., “installation,” “repair,” “maintenance”) and a duration in days. You’re trying to group these into two categories: *“high-priority”* and *“low-priority.”* The problem? The work types and work requests are *tangentially related*.

> *“I was given a list of work types that could be grouped into 1 of 2 categories exclusively.”*
> *“The problem was… the ‘work types’ and work requests were at best tangentially related.”*

So I had to manually read each work type and map it to a work request. It was a *shudder-inducing* task. AI, on the other hand, would have *automated* that. But it would also have *misunderstood* the relationship between the two.

### 2. **The Math and Logic Job**

AI is great at math and logic. If you need to calculate the total time spent on a process, or create a formula that accounts for variables like labor hours, weather, or equipment downtime, AI can handle it. For example, I once built a spreadsheet that calculated potential savings in a process. The formulas were precise, and the logic was sound.

> *“Traditional programming methods work on maths and logic that is sound and offers no chance for interpretation.”*

So even if AI could suggest the numbers, I’d never trust it to actually run the calculation. It’s like trusting a robot to drive a car when it’s not built for that.

## When AI is the Best Choice

### 1. **Finding Connections**

AI excels at identifying patterns and relationships within large datasets. This is invaluable for tasks like customer segmentation, fraud detection, and predictive maintenance.

### 2. **Automating Repetitive Tasks**

Many tasks are simply too repetitive and time-consuming for humans to perform efficiently. AI-powered automation can free up valuable time and resources.

### 3. **Suggesting Numbers or Constants**

While AI shouldn't be trusted to run calculations, it can be helpful in suggesting potential numbers or constants to use in those calculations.

## The Human vs. AI Divide

AI is good at *finding connections* and *handling ambiguity*, but it’s *not good at precision*. When you need to ensure that a calculation is accurate, or that a mapping is flawless, AI is not the best choice. And that’s where humans shine. We’re good at *seeing* the connection between two things, even if it’s not obvious. We’re good at *precision* and *accuracy*.

> *“I was given a list of work types that could be grouped into 1 of 2 categories exclusively.”*
> *“The problem was… the ‘work types’ and work requests were at best tangentially related.”*

So I had to manually read each work type and map it to a work request. It was a *shudder-inducing* task.

## The Final Thought

So, in summary:

*   **AI is not the best choice** when you need precision, accuracy, or a human touch.
*   **AI is the best choice** when you need to handle ambiguity, find connections, or automate repetitive tasks.

And that’s why I’m a journalist, a developer, and a DevOps expert. I know when to trust the machine and when to rely on my brain.

> *“When in doubt, just do it.”*

## Editable Structure for Easy Customization

### 📝 Title When to use AI

### 🧠 Introduction

*   Briefly explain the question and the tone.

### 🧩 Sections

1.  **When AI is Not the Best Choice**
    *   Subpoints:
        *   Fuzzy logic dilemmas
        *   Manual mapping tasks
        *   Precision vs. AI’s “fuzzy” logic
2.  **When AI is the Best Choice**
    *   Subpoints:
        *   Math and logic tasks
        *   Automation of repetitive tasks
        *   Suggesting numbers or constants
3.  **The Human vs. AI Divide**
    *   Highlight the importance of human judgment in critical tasks
4.  **Final Thought**
    *   Encourage readers to think critically about when to use AI

### 📝 Conclusion

*   Wrap up the key points and reinforce the message.

## Tips for Editing

*   Replace the example about the spreadsheet with your own scenario.
*   Add a personal anecdote or a relatable example.
*   Use humor to keep the tone light and engaging.
*   Add a call to action: “Next time you’re stuck, ask yourself: ‘Is this a task for AI or a task for me?’”